#include "test.h"

#include "ui_form.h"
#include "mypaintlayer.h"

#include <marble/MarbleWidget.h>

#include <QTimer>
#include <QCheckBox>

static const qreal lat = 43.60525;
static const qreal lon = 51.20879;
static const qreal alt = 0.0;
static GeoDataCoordinates home(lon, lat, alt, GeoDataCoordinates::Degree);

class Test::PrivateData
{
   public:
      PrivateData()
      {}

      Ui::Test ui;
      Marble::MarbleWidget * mapWidget;
      MyPaintLayer * layer;
};

Test::Test()
: QWidget()
, p_impl(new PrivateData())
{
   setupUi();
   setupMap();
   setupSlots();
}

void Test::setupUi()
{
   p_impl->ui.setupUi(this);
}

void Test::setupMap()
{
   p_impl->mapWidget = new MarbleWidget;

   // Create and register our paint layer
   p_impl->layer = new MyPaintLayer(p_impl->mapWidget);
   p_impl->layer->setCenter(home);

   // Uncomment for older versions of Marble:
   // mapWidget->map()->model()->addLayer(layer);
   p_impl->mapWidget->addLayer(p_impl->layer);

   // Install an event handler: Pressing + will change the layer we paint at
   p_impl->mapWidget->installEventFilter(p_impl->layer);

   // Finish widget creation.
   //mapWidget->setMapThemeId("earth/bluemarble/bluemarble.dgml");
   p_impl->mapWidget->setMapThemeId("earth/openstreetmap/openstreetmap.dgml");
   p_impl->mapWidget->setProjection(Marble::Mercator);
   p_impl->mapWidget->centerOn(home);

   p_impl->ui.layout->addWidget(p_impl->mapWidget);

   // Update each second to give the clock second resolution
   QTimer * seconds = new QTimer();
   seconds->setInterval(1000);
   QObject::connect(seconds, SIGNAL(timeout()), p_impl->mapWidget, SLOT(update()));
   seconds->start();
}

void Test::setupSlots()
{
   QObject::connect(p_impl->ui.cb_brush, SIGNAL(toggled(bool)), this, SLOT(onBrushChanged()));
   QObject::connect(p_impl->ui.cb_grid, SIGNAL(toggled(bool)), this, SLOT(onGridChanged()));
}

Test::~Test()
{}

void Test::onBrushChanged()
{
   // update flag
   p_impl->layer->setBrushEnabled(p_impl->ui.cb_brush->isChecked());

   // force painting
   p_impl->mapWidget->update();
}

void Test::onGridChanged()
{
   // update flag
   p_impl->mapWidget->setShowGrid(p_impl->ui.cb_grid->isChecked());

   // force painting
   p_impl->mapWidget->update();
}

void Test::onColorPressed()
{
   
}
